@@ -333,7 +333,15 @@ int dvdinput_setup(void)
     return 1;
     
   } else {
-    fprintf(stderr, "libdvdread: Encrypted DVD support unavailable.\n");
+    fprintf(stderr, "libdvdread: Encrypted DVD support unavailable.\n"
+	    "************************************************\n"
+	    "**                                            **\n"
+	    "**  No css library available. See             **\n"
+	    "**  /usr/share/doc/libdvdread3/README.Debian  **\n"
+	    "**  for more information.                     **\n"
+	    "**                                            **\n"
+	    "************************************************\n"
+	    );
 
     /* libdvdcss replacement functions */
     dvdinput_open  = file_open;
